instrumenttools.AltoFlute
=========================

.. abjad-lineage:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute

.. autoclass:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoFlute.AltoFlute.AltoFlute.__repr__
   :noindex:
